pub struct TransientEnvMap(/* private fields */);Expand description
This is a transparent value type wrapping [FxIndexMap<RcStr,RcStr>].
Like EnvMap, but with serialization = "skip" to avoid storing
environment variables (which may contain secrets) in the persistent cache.
Implementations
Sourceimpl TransientEnvMap
impl TransientEnvMap
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.